# Colorado River at Potash, UT (channel control)

## USGS Gage ID: 09185600

## Control
The stream reach is in an incised river canyon in sandstone and mudstone. 
Channel control is in affect at all stages. 
A sharp bend of the river is present just upstream of the gage. 
The channel is straight for about 1,000 ft downstream before it begins a broad bend to the right.

## Stage Ranges
- Channel control: 4.0 to 22.0 ft